# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Session.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Node' not in _M_omero.model.__dict__:
    _M_omero.model._t_Node = IcePy.declareClass('::omero::model::Node')
    _M_omero.model._t_NodePrx = IcePy.declareProxy('::omero::model::Node')

if 'Experimenter' not in _M_omero.model.__dict__:
    _M_omero.model._t_Experimenter = IcePy.declareClass('::omero::model::Experimenter')
    _M_omero.model._t_ExperimenterPrx = IcePy.declareProxy('::omero::model::Experimenter')

if 'Event' not in _M_omero.model.__dict__:
    _M_omero.model._t_Event = IcePy.declareClass('::omero::model::Event')
    _M_omero.model._t_EventPrx = IcePy.declareProxy('::omero::model::Event')

if 'SessionAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_SessionAnnotationLink = IcePy.declareClass('::omero::model::SessionAnnotationLink')
    _M_omero.model._t_SessionAnnotationLinkPrx = IcePy.declareProxy('::omero::model::SessionAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_SessionEventsSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_SessionEventsSeq = IcePy.defineSequence('::omero::model::SessionEventsSeq', (), _M_omero.model._t_Event)

if '_t_SessionAnnotationLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_SessionAnnotationLinksSeq = IcePy.defineSequence('::omero::model::SessionAnnotationLinksSeq', (), _M_omero.model._t_SessionAnnotationLink)

if '_t_SessionLinkedAnnotationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_SessionLinkedAnnotationSeq = IcePy.defineSequence('::omero::model::SessionLinkedAnnotationSeq', (), _M_omero.model._t_Annotation)

if 'Session' not in _M_omero.model.__dict__:
    _M_omero.model.Session = Ice.createTempClass()
    class Session(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _node=None, _uuid=None, _owner=None, _sudoer=None, _timeToIdle=None, _timeToLive=None, _started=None, _closed=None, _message=None, _defaultEventType=None, _userAgent=None, _userIP=None, _eventsSeq=None, _eventsLoaded=False, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None):
            if Ice.getType(self) == _M_omero.model.Session:
                raise RuntimeError('omero.model.Session is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._node = _node
            self._uuid = _uuid
            self._owner = _owner
            self._sudoer = _sudoer
            self._timeToIdle = _timeToIdle
            self._timeToLive = _timeToLive
            self._started = _started
            self._closed = _closed
            self._message = _message
            self._defaultEventType = _defaultEventType
            self._userAgent = _userAgent
            self._userIP = _userIP
            self._eventsSeq = _eventsSeq
            self._eventsLoaded = _eventsLoaded
            self._annotationLinksSeq = _annotationLinksSeq
            self._annotationLinksLoaded = _annotationLinksLoaded
            self._annotationLinksCountPerOwner = _annotationLinksCountPerOwner

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::Session')

        def ice_id(self, current=None):
            return '::omero::model::Session'

        def ice_staticId():
            return '::omero::model::Session'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getNode(self, current=None):
            pass

        def setNode(self, theNode, current=None):
            pass

        def getUuid(self, current=None):
            pass

        def setUuid(self, theUuid, current=None):
            pass

        def getOwner(self, current=None):
            pass

        def setOwner(self, theOwner, current=None):
            pass

        def getSudoer(self, current=None):
            pass

        def setSudoer(self, theSudoer, current=None):
            pass

        def getTimeToIdle(self, current=None):
            pass

        def setTimeToIdle(self, theTimeToIdle, current=None):
            pass

        def getTimeToLive(self, current=None):
            pass

        def setTimeToLive(self, theTimeToLive, current=None):
            pass

        def getStarted(self, current=None):
            pass

        def setStarted(self, theStarted, current=None):
            pass

        def getClosed(self, current=None):
            pass

        def setClosed(self, theClosed, current=None):
            pass

        def getMessage(self, current=None):
            pass

        def setMessage(self, theMessage, current=None):
            pass

        def getDefaultEventType(self, current=None):
            pass

        def setDefaultEventType(self, theDefaultEventType, current=None):
            pass

        def getUserAgent(self, current=None):
            pass

        def setUserAgent(self, theUserAgent, current=None):
            pass

        def getUserIP(self, current=None):
            pass

        def setUserIP(self, theUserIP, current=None):
            pass

        def unloadEvents(self, current=None):
            pass

        def sizeOfEvents(self, current=None):
            pass

        def copyEvents(self, current=None):
            pass

        def addEvent(self, target, current=None):
            pass

        def addAllEventSet(self, targets, current=None):
            pass

        def removeEvent(self, theTarget, current=None):
            pass

        def removeAllEventSet(self, targets, current=None):
            pass

        def clearEvents(self, current=None):
            pass

        def reloadEvents(self, toCopy, current=None):
            pass

        def unloadAnnotationLinks(self, current=None):
            pass

        def sizeOfAnnotationLinks(self, current=None):
            pass

        def copyAnnotationLinks(self, current=None):
            pass

        def addSessionAnnotationLink(self, target, current=None):
            pass

        def addAllSessionAnnotationLinkSet(self, targets, current=None):
            pass

        def removeSessionAnnotationLink(self, theTarget, current=None):
            pass

        def removeAllSessionAnnotationLinkSet(self, targets, current=None):
            pass

        def clearAnnotationLinks(self, current=None):
            pass

        def reloadAnnotationLinks(self, toCopy, current=None):
            pass

        def getAnnotationLinksCountPerOwner(self, current=None):
            pass

        def linkAnnotation(self, addition, current=None):
            pass

        def addSessionAnnotationLinkToBoth(self, link, bothSides, current=None):
            pass

        def findSessionAnnotationLink(self, removal, current=None):
            pass

        def unlinkAnnotation(self, removal, current=None):
            pass

        def removeSessionAnnotationLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedAnnotationList(self, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Session)

        __repr__ = __str__

    _M_omero.model.SessionPrx = Ice.createTempClass()
    class SessionPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.Session._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.Session._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.Session._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.Session._op_setVersion.end(self, _r)

        def getNode(self, _ctx=None):
            return _M_omero.model.Session._op_getNode.invoke(self, ((), _ctx))

        def begin_getNode(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_getNode.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getNode(self, _r):
            return _M_omero.model.Session._op_getNode.end(self, _r)

        def setNode(self, theNode, _ctx=None):
            return _M_omero.model.Session._op_setNode.invoke(self, ((theNode, ), _ctx))

        def begin_setNode(self, theNode, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_setNode.begin(self, ((theNode, ), _response, _ex, _sent, _ctx))

        def end_setNode(self, _r):
            return _M_omero.model.Session._op_setNode.end(self, _r)

        def getUuid(self, _ctx=None):
            return _M_omero.model.Session._op_getUuid.invoke(self, ((), _ctx))

        def begin_getUuid(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_getUuid.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getUuid(self, _r):
            return _M_omero.model.Session._op_getUuid.end(self, _r)

        def setUuid(self, theUuid, _ctx=None):
            return _M_omero.model.Session._op_setUuid.invoke(self, ((theUuid, ), _ctx))

        def begin_setUuid(self, theUuid, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_setUuid.begin(self, ((theUuid, ), _response, _ex, _sent, _ctx))

        def end_setUuid(self, _r):
            return _M_omero.model.Session._op_setUuid.end(self, _r)

        def getOwner(self, _ctx=None):
            return _M_omero.model.Session._op_getOwner.invoke(self, ((), _ctx))

        def begin_getOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_getOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getOwner(self, _r):
            return _M_omero.model.Session._op_getOwner.end(self, _r)

        def setOwner(self, theOwner, _ctx=None):
            return _M_omero.model.Session._op_setOwner.invoke(self, ((theOwner, ), _ctx))

        def begin_setOwner(self, theOwner, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_setOwner.begin(self, ((theOwner, ), _response, _ex, _sent, _ctx))

        def end_setOwner(self, _r):
            return _M_omero.model.Session._op_setOwner.end(self, _r)

        def getSudoer(self, _ctx=None):
            return _M_omero.model.Session._op_getSudoer.invoke(self, ((), _ctx))

        def begin_getSudoer(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_getSudoer.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getSudoer(self, _r):
            return _M_omero.model.Session._op_getSudoer.end(self, _r)

        def setSudoer(self, theSudoer, _ctx=None):
            return _M_omero.model.Session._op_setSudoer.invoke(self, ((theSudoer, ), _ctx))

        def begin_setSudoer(self, theSudoer, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_setSudoer.begin(self, ((theSudoer, ), _response, _ex, _sent, _ctx))

        def end_setSudoer(self, _r):
            return _M_omero.model.Session._op_setSudoer.end(self, _r)

        def getTimeToIdle(self, _ctx=None):
            return _M_omero.model.Session._op_getTimeToIdle.invoke(self, ((), _ctx))

        def begin_getTimeToIdle(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_getTimeToIdle.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTimeToIdle(self, _r):
            return _M_omero.model.Session._op_getTimeToIdle.end(self, _r)

        def setTimeToIdle(self, theTimeToIdle, _ctx=None):
            return _M_omero.model.Session._op_setTimeToIdle.invoke(self, ((theTimeToIdle, ), _ctx))

        def begin_setTimeToIdle(self, theTimeToIdle, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_setTimeToIdle.begin(self, ((theTimeToIdle, ), _response, _ex, _sent, _ctx))

        def end_setTimeToIdle(self, _r):
            return _M_omero.model.Session._op_setTimeToIdle.end(self, _r)

        def getTimeToLive(self, _ctx=None):
            return _M_omero.model.Session._op_getTimeToLive.invoke(self, ((), _ctx))

        def begin_getTimeToLive(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_getTimeToLive.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTimeToLive(self, _r):
            return _M_omero.model.Session._op_getTimeToLive.end(self, _r)

        def setTimeToLive(self, theTimeToLive, _ctx=None):
            return _M_omero.model.Session._op_setTimeToLive.invoke(self, ((theTimeToLive, ), _ctx))

        def begin_setTimeToLive(self, theTimeToLive, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_setTimeToLive.begin(self, ((theTimeToLive, ), _response, _ex, _sent, _ctx))

        def end_setTimeToLive(self, _r):
            return _M_omero.model.Session._op_setTimeToLive.end(self, _r)

        def getStarted(self, _ctx=None):
            return _M_omero.model.Session._op_getStarted.invoke(self, ((), _ctx))

        def begin_getStarted(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_getStarted.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getStarted(self, _r):
            return _M_omero.model.Session._op_getStarted.end(self, _r)

        def setStarted(self, theStarted, _ctx=None):
            return _M_omero.model.Session._op_setStarted.invoke(self, ((theStarted, ), _ctx))

        def begin_setStarted(self, theStarted, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_setStarted.begin(self, ((theStarted, ), _response, _ex, _sent, _ctx))

        def end_setStarted(self, _r):
            return _M_omero.model.Session._op_setStarted.end(self, _r)

        def getClosed(self, _ctx=None):
            return _M_omero.model.Session._op_getClosed.invoke(self, ((), _ctx))

        def begin_getClosed(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_getClosed.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getClosed(self, _r):
            return _M_omero.model.Session._op_getClosed.end(self, _r)

        def setClosed(self, theClosed, _ctx=None):
            return _M_omero.model.Session._op_setClosed.invoke(self, ((theClosed, ), _ctx))

        def begin_setClosed(self, theClosed, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_setClosed.begin(self, ((theClosed, ), _response, _ex, _sent, _ctx))

        def end_setClosed(self, _r):
            return _M_omero.model.Session._op_setClosed.end(self, _r)

        def getMessage(self, _ctx=None):
            return _M_omero.model.Session._op_getMessage.invoke(self, ((), _ctx))

        def begin_getMessage(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_getMessage.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getMessage(self, _r):
            return _M_omero.model.Session._op_getMessage.end(self, _r)

        def setMessage(self, theMessage, _ctx=None):
            return _M_omero.model.Session._op_setMessage.invoke(self, ((theMessage, ), _ctx))

        def begin_setMessage(self, theMessage, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_setMessage.begin(self, ((theMessage, ), _response, _ex, _sent, _ctx))

        def end_setMessage(self, _r):
            return _M_omero.model.Session._op_setMessage.end(self, _r)

        def getDefaultEventType(self, _ctx=None):
            return _M_omero.model.Session._op_getDefaultEventType.invoke(self, ((), _ctx))

        def begin_getDefaultEventType(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_getDefaultEventType.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDefaultEventType(self, _r):
            return _M_omero.model.Session._op_getDefaultEventType.end(self, _r)

        def setDefaultEventType(self, theDefaultEventType, _ctx=None):
            return _M_omero.model.Session._op_setDefaultEventType.invoke(self, ((theDefaultEventType, ), _ctx))

        def begin_setDefaultEventType(self, theDefaultEventType, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_setDefaultEventType.begin(self, ((theDefaultEventType, ), _response, _ex, _sent, _ctx))

        def end_setDefaultEventType(self, _r):
            return _M_omero.model.Session._op_setDefaultEventType.end(self, _r)

        def getUserAgent(self, _ctx=None):
            return _M_omero.model.Session._op_getUserAgent.invoke(self, ((), _ctx))

        def begin_getUserAgent(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_getUserAgent.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getUserAgent(self, _r):
            return _M_omero.model.Session._op_getUserAgent.end(self, _r)

        def setUserAgent(self, theUserAgent, _ctx=None):
            return _M_omero.model.Session._op_setUserAgent.invoke(self, ((theUserAgent, ), _ctx))

        def begin_setUserAgent(self, theUserAgent, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_setUserAgent.begin(self, ((theUserAgent, ), _response, _ex, _sent, _ctx))

        def end_setUserAgent(self, _r):
            return _M_omero.model.Session._op_setUserAgent.end(self, _r)

        def getUserIP(self, _ctx=None):
            return _M_omero.model.Session._op_getUserIP.invoke(self, ((), _ctx))

        def begin_getUserIP(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_getUserIP.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getUserIP(self, _r):
            return _M_omero.model.Session._op_getUserIP.end(self, _r)

        def setUserIP(self, theUserIP, _ctx=None):
            return _M_omero.model.Session._op_setUserIP.invoke(self, ((theUserIP, ), _ctx))

        def begin_setUserIP(self, theUserIP, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_setUserIP.begin(self, ((theUserIP, ), _response, _ex, _sent, _ctx))

        def end_setUserIP(self, _r):
            return _M_omero.model.Session._op_setUserIP.end(self, _r)

        def unloadEvents(self, _ctx=None):
            return _M_omero.model.Session._op_unloadEvents.invoke(self, ((), _ctx))

        def begin_unloadEvents(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_unloadEvents.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadEvents(self, _r):
            return _M_omero.model.Session._op_unloadEvents.end(self, _r)

        def sizeOfEvents(self, _ctx=None):
            return _M_omero.model.Session._op_sizeOfEvents.invoke(self, ((), _ctx))

        def begin_sizeOfEvents(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_sizeOfEvents.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfEvents(self, _r):
            return _M_omero.model.Session._op_sizeOfEvents.end(self, _r)

        def copyEvents(self, _ctx=None):
            return _M_omero.model.Session._op_copyEvents.invoke(self, ((), _ctx))

        def begin_copyEvents(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_copyEvents.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyEvents(self, _r):
            return _M_omero.model.Session._op_copyEvents.end(self, _r)

        def addEvent(self, target, _ctx=None):
            return _M_omero.model.Session._op_addEvent.invoke(self, ((target, ), _ctx))

        def begin_addEvent(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_addEvent.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addEvent(self, _r):
            return _M_omero.model.Session._op_addEvent.end(self, _r)

        def addAllEventSet(self, targets, _ctx=None):
            return _M_omero.model.Session._op_addAllEventSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllEventSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_addAllEventSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllEventSet(self, _r):
            return _M_omero.model.Session._op_addAllEventSet.end(self, _r)

        def removeEvent(self, theTarget, _ctx=None):
            return _M_omero.model.Session._op_removeEvent.invoke(self, ((theTarget, ), _ctx))

        def begin_removeEvent(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_removeEvent.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeEvent(self, _r):
            return _M_omero.model.Session._op_removeEvent.end(self, _r)

        def removeAllEventSet(self, targets, _ctx=None):
            return _M_omero.model.Session._op_removeAllEventSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllEventSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_removeAllEventSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllEventSet(self, _r):
            return _M_omero.model.Session._op_removeAllEventSet.end(self, _r)

        def clearEvents(self, _ctx=None):
            return _M_omero.model.Session._op_clearEvents.invoke(self, ((), _ctx))

        def begin_clearEvents(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_clearEvents.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearEvents(self, _r):
            return _M_omero.model.Session._op_clearEvents.end(self, _r)

        def reloadEvents(self, toCopy, _ctx=None):
            return _M_omero.model.Session._op_reloadEvents.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadEvents(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_reloadEvents.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadEvents(self, _r):
            return _M_omero.model.Session._op_reloadEvents.end(self, _r)

        def unloadAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Session._op_unloadAnnotationLinks.invoke(self, ((), _ctx))

        def begin_unloadAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_unloadAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadAnnotationLinks(self, _r):
            return _M_omero.model.Session._op_unloadAnnotationLinks.end(self, _r)

        def sizeOfAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Session._op_sizeOfAnnotationLinks.invoke(self, ((), _ctx))

        def begin_sizeOfAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_sizeOfAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfAnnotationLinks(self, _r):
            return _M_omero.model.Session._op_sizeOfAnnotationLinks.end(self, _r)

        def copyAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Session._op_copyAnnotationLinks.invoke(self, ((), _ctx))

        def begin_copyAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_copyAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyAnnotationLinks(self, _r):
            return _M_omero.model.Session._op_copyAnnotationLinks.end(self, _r)

        def addSessionAnnotationLink(self, target, _ctx=None):
            return _M_omero.model.Session._op_addSessionAnnotationLink.invoke(self, ((target, ), _ctx))

        def begin_addSessionAnnotationLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_addSessionAnnotationLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addSessionAnnotationLink(self, _r):
            return _M_omero.model.Session._op_addSessionAnnotationLink.end(self, _r)

        def addAllSessionAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Session._op_addAllSessionAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllSessionAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_addAllSessionAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllSessionAnnotationLinkSet(self, _r):
            return _M_omero.model.Session._op_addAllSessionAnnotationLinkSet.end(self, _r)

        def removeSessionAnnotationLink(self, theTarget, _ctx=None):
            return _M_omero.model.Session._op_removeSessionAnnotationLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeSessionAnnotationLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_removeSessionAnnotationLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeSessionAnnotationLink(self, _r):
            return _M_omero.model.Session._op_removeSessionAnnotationLink.end(self, _r)

        def removeAllSessionAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Session._op_removeAllSessionAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllSessionAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_removeAllSessionAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllSessionAnnotationLinkSet(self, _r):
            return _M_omero.model.Session._op_removeAllSessionAnnotationLinkSet.end(self, _r)

        def clearAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Session._op_clearAnnotationLinks.invoke(self, ((), _ctx))

        def begin_clearAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_clearAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearAnnotationLinks(self, _r):
            return _M_omero.model.Session._op_clearAnnotationLinks.end(self, _r)

        def reloadAnnotationLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Session._op_reloadAnnotationLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadAnnotationLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_reloadAnnotationLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadAnnotationLinks(self, _r):
            return _M_omero.model.Session._op_reloadAnnotationLinks.end(self, _r)

        def getAnnotationLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Session._op_getAnnotationLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getAnnotationLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_getAnnotationLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAnnotationLinksCountPerOwner(self, _r):
            return _M_omero.model.Session._op_getAnnotationLinksCountPerOwner.end(self, _r)

        def linkAnnotation(self, addition, _ctx=None):
            return _M_omero.model.Session._op_linkAnnotation.invoke(self, ((addition, ), _ctx))

        def begin_linkAnnotation(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_linkAnnotation.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkAnnotation(self, _r):
            return _M_omero.model.Session._op_linkAnnotation.end(self, _r)

        def addSessionAnnotationLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Session._op_addSessionAnnotationLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addSessionAnnotationLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_addSessionAnnotationLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addSessionAnnotationLinkToBoth(self, _r):
            return _M_omero.model.Session._op_addSessionAnnotationLinkToBoth.end(self, _r)

        def findSessionAnnotationLink(self, removal, _ctx=None):
            return _M_omero.model.Session._op_findSessionAnnotationLink.invoke(self, ((removal, ), _ctx))

        def begin_findSessionAnnotationLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_findSessionAnnotationLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findSessionAnnotationLink(self, _r):
            return _M_omero.model.Session._op_findSessionAnnotationLink.end(self, _r)

        def unlinkAnnotation(self, removal, _ctx=None):
            return _M_omero.model.Session._op_unlinkAnnotation.invoke(self, ((removal, ), _ctx))

        def begin_unlinkAnnotation(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_unlinkAnnotation.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkAnnotation(self, _r):
            return _M_omero.model.Session._op_unlinkAnnotation.end(self, _r)

        def removeSessionAnnotationLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Session._op_removeSessionAnnotationLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeSessionAnnotationLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_removeSessionAnnotationLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeSessionAnnotationLinkFromBoth(self, _r):
            return _M_omero.model.Session._op_removeSessionAnnotationLinkFromBoth.end(self, _r)

        def linkedAnnotationList(self, _ctx=None):
            return _M_omero.model.Session._op_linkedAnnotationList.invoke(self, ((), _ctx))

        def begin_linkedAnnotationList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Session._op_linkedAnnotationList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedAnnotationList(self, _r):
            return _M_omero.model.Session._op_linkedAnnotationList.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.SessionPrx.ice_checkedCast(proxy, '::omero::model::Session', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.SessionPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Session'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_SessionPrx = IcePy.defineProxy('::omero::model::Session', SessionPrx)

    _M_omero.model._t_Session = IcePy.declareClass('::omero::model::Session')

    _M_omero.model._t_Session = IcePy.defineClass('::omero::model::Session', Session, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_node', (), _M_omero.model._t_Node, False, 0),
        ('_uuid', (), _M_omero._t_RString, False, 0),
        ('_owner', (), _M_omero.model._t_Experimenter, False, 0),
        ('_sudoer', (), _M_omero.model._t_Experimenter, False, 0),
        ('_timeToIdle', (), _M_omero._t_RLong, False, 0),
        ('_timeToLive', (), _M_omero._t_RLong, False, 0),
        ('_started', (), _M_omero._t_RTime, False, 0),
        ('_closed', (), _M_omero._t_RTime, False, 0),
        ('_message', (), _M_omero._t_RString, False, 0),
        ('_defaultEventType', (), _M_omero._t_RString, False, 0),
        ('_userAgent', (), _M_omero._t_RString, False, 0),
        ('_userIP', (), _M_omero._t_RString, False, 0),
        ('_eventsSeq', (), _M_omero.model._t_SessionEventsSeq, False, 0),
        ('_eventsLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksSeq', (), _M_omero.model._t_SessionAnnotationLinksSeq, False, 0),
        ('_annotationLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0)
    ))
    Session._ice_type = _M_omero.model._t_Session

    Session._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Session._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Session._op_getNode = IcePy.Operation('getNode', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Node, False, 0), ())
    Session._op_setNode = IcePy.Operation('setNode', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Node, False, 0),), (), None, ())
    Session._op_getUuid = IcePy.Operation('getUuid', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Session._op_setUuid = IcePy.Operation('setUuid', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Session._op_getOwner = IcePy.Operation('getOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Experimenter, False, 0), ())
    Session._op_setOwner = IcePy.Operation('setOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Experimenter, False, 0),), (), None, ())
    Session._op_getSudoer = IcePy.Operation('getSudoer', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Experimenter, False, 0), ())
    Session._op_setSudoer = IcePy.Operation('setSudoer', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Experimenter, False, 0),), (), None, ())
    Session._op_getTimeToIdle = IcePy.Operation('getTimeToIdle', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RLong, False, 0), ())
    Session._op_setTimeToIdle = IcePy.Operation('setTimeToIdle', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RLong, False, 0),), (), None, ())
    Session._op_getTimeToLive = IcePy.Operation('getTimeToLive', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RLong, False, 0), ())
    Session._op_setTimeToLive = IcePy.Operation('setTimeToLive', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RLong, False, 0),), (), None, ())
    Session._op_getStarted = IcePy.Operation('getStarted', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RTime, False, 0), ())
    Session._op_setStarted = IcePy.Operation('setStarted', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RTime, False, 0),), (), None, ())
    Session._op_getClosed = IcePy.Operation('getClosed', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RTime, False, 0), ())
    Session._op_setClosed = IcePy.Operation('setClosed', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RTime, False, 0),), (), None, ())
    Session._op_getMessage = IcePy.Operation('getMessage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Session._op_setMessage = IcePy.Operation('setMessage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Session._op_getDefaultEventType = IcePy.Operation('getDefaultEventType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Session._op_setDefaultEventType = IcePy.Operation('setDefaultEventType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Session._op_getUserAgent = IcePy.Operation('getUserAgent', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Session._op_setUserAgent = IcePy.Operation('setUserAgent', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Session._op_getUserIP = IcePy.Operation('getUserIP', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Session._op_setUserIP = IcePy.Operation('setUserIP', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Session._op_unloadEvents = IcePy.Operation('unloadEvents', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Session._op_sizeOfEvents = IcePy.Operation('sizeOfEvents', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Session._op_copyEvents = IcePy.Operation('copyEvents', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_SessionEventsSeq, False, 0), ())
    Session._op_addEvent = IcePy.Operation('addEvent', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Event, False, 0),), (), None, ())
    Session._op_addAllEventSet = IcePy.Operation('addAllEventSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_SessionEventsSeq, False, 0),), (), None, ())
    Session._op_removeEvent = IcePy.Operation('removeEvent', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Event, False, 0),), (), None, ())
    Session._op_removeAllEventSet = IcePy.Operation('removeAllEventSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_SessionEventsSeq, False, 0),), (), None, ())
    Session._op_clearEvents = IcePy.Operation('clearEvents', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Session._op_reloadEvents = IcePy.Operation('reloadEvents', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Session, False, 0),), (), None, ())
    Session._op_unloadAnnotationLinks = IcePy.Operation('unloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Session._op_sizeOfAnnotationLinks = IcePy.Operation('sizeOfAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Session._op_copyAnnotationLinks = IcePy.Operation('copyAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_SessionAnnotationLinksSeq, False, 0), ())
    Session._op_addSessionAnnotationLink = IcePy.Operation('addSessionAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_SessionAnnotationLink, False, 0),), (), None, ())
    Session._op_addAllSessionAnnotationLinkSet = IcePy.Operation('addAllSessionAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_SessionAnnotationLinksSeq, False, 0),), (), None, ())
    Session._op_removeSessionAnnotationLink = IcePy.Operation('removeSessionAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_SessionAnnotationLink, False, 0),), (), None, ())
    Session._op_removeAllSessionAnnotationLinkSet = IcePy.Operation('removeAllSessionAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_SessionAnnotationLinksSeq, False, 0),), (), None, ())
    Session._op_clearAnnotationLinks = IcePy.Operation('clearAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Session._op_reloadAnnotationLinks = IcePy.Operation('reloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Session, False, 0),), (), None, ())
    Session._op_getAnnotationLinksCountPerOwner = IcePy.Operation('getAnnotationLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Session._op_linkAnnotation = IcePy.Operation('linkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_SessionAnnotationLink, False, 0), ())
    Session._op_addSessionAnnotationLinkToBoth = IcePy.Operation('addSessionAnnotationLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_SessionAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Session._op_findSessionAnnotationLink = IcePy.Operation('findSessionAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_SessionAnnotationLinksSeq, False, 0), ())
    Session._op_unlinkAnnotation = IcePy.Operation('unlinkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    Session._op_removeSessionAnnotationLinkFromBoth = IcePy.Operation('removeSessionAnnotationLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_SessionAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Session._op_linkedAnnotationList = IcePy.Operation('linkedAnnotationList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_SessionLinkedAnnotationSeq, False, 0), ())

    _M_omero.model.Session = Session
    del Session

    _M_omero.model.SessionPrx = SessionPrx
    del SessionPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (C) 2011 Glencoe Software, Inc. All Rights Reserved.
# Use is subject to license terms supplied in LICENSE.txt
#

"""
Load modules with automatic updating of Ice modules.
"""

import Ice
update = getattr(Ice, "updateModules", None)


def load(target):
    """
    uses __import__ followed by Ice.updateModules if available.

    """
    __import__(target)
    Ice.updateModules()



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `SystemF.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_RTypes_ice
import Ice_BuiltinSequences_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Start of module omero
__name__ = 'omero'

# Start of module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')
__name__ = 'omero.sys'

if '_t_LongList' not in _M_omero.sys.__dict__:
    _M_omero.sys._t_LongList = IcePy.defineSequence('::omero::sys::LongList', (), IcePy._t_long)

if '_t_IntList' not in _M_omero.sys.__dict__:
    _M_omero.sys._t_IntList = IcePy.defineSequence('::omero::sys::IntList', (), IcePy._t_int)

if '_t_CountMap' not in _M_omero.sys.__dict__:
    _M_omero.sys._t_CountMap = IcePy.defineDictionary('::omero::sys::CountMap', (), IcePy._t_long, IcePy._t_long)

if '_t_ParamMap' not in _M_omero.sys.__dict__:
    _M_omero.sys._t_ParamMap = IcePy.defineDictionary('::omero::sys::ParamMap', (), IcePy._t_string, _M_omero._t_RType)

if '_t_IdByteMap' not in _M_omero.sys.__dict__:
    _M_omero.sys._t_IdByteMap = IcePy.defineDictionary('::omero::sys::IdByteMap', (), IcePy._t_long, _M_Ice._t_ByteSeq)

if 'EventContext' not in _M_omero.sys.__dict__:
    _M_omero.sys._t_EventContext = IcePy.declareClass('::omero::sys::EventContext')
    _M_omero.sys._t_EventContextPrx = IcePy.declareProxy('::omero::sys::EventContext')

# End of module omero.sys

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Experimenter.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'GroupExperimenterMap' not in _M_omero.model.__dict__:
    _M_omero.model._t_GroupExperimenterMap = IcePy.declareClass('::omero::model::GroupExperimenterMap')
    _M_omero.model._t_GroupExperimenterMapPrx = IcePy.declareProxy('::omero::model::GroupExperimenterMap')

if 'ExperimenterGroup' not in _M_omero.model.__dict__:
    _M_omero.model._t_ExperimenterGroup = IcePy.declareClass('::omero::model::ExperimenterGroup')
    _M_omero.model._t_ExperimenterGroupPrx = IcePy.declareProxy('::omero::model::ExperimenterGroup')

if 'ExperimenterAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_ExperimenterAnnotationLink = IcePy.declareClass('::omero::model::ExperimenterAnnotationLink')
    _M_omero.model._t_ExperimenterAnnotationLinkPrx = IcePy.declareProxy('::omero::model::ExperimenterAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_ExperimenterGroupExperimenterMapSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ExperimenterGroupExperimenterMapSeq = IcePy.defineSequence('::omero::model::ExperimenterGroupExperimenterMapSeq', (), _M_omero.model._t_GroupExperimenterMap)

if '_t_ExperimenterLinkedExperimenterGroupSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ExperimenterLinkedExperimenterGroupSeq = IcePy.defineSequence('::omero::model::ExperimenterLinkedExperimenterGroupSeq', (), _M_omero.model._t_ExperimenterGroup)

if '_t_ExperimenterAnnotationLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ExperimenterAnnotationLinksSeq = IcePy.defineSequence('::omero::model::ExperimenterAnnotationLinksSeq', (), _M_omero.model._t_ExperimenterAnnotationLink)

if '_t_ExperimenterLinkedAnnotationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ExperimenterLinkedAnnotationSeq = IcePy.defineSequence('::omero::model::ExperimenterLinkedAnnotationSeq', (), _M_omero.model._t_Annotation)

if 'Experimenter' not in _M_omero.model.__dict__:
    _M_omero.model.Experimenter = Ice.createTempClass()
    class Experimenter(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _groupExperimenterMapSeq=None, _groupExperimenterMapLoaded=False, _omeName=None, _firstName=None, _middleName=None, _lastName=None, _institution=None, _ldap=None, _email=None, _config=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None):
            if Ice.getType(self) == _M_omero.model.Experimenter:
                raise RuntimeError('omero.model.Experimenter is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._groupExperimenterMapSeq = _groupExperimenterMapSeq
            self._groupExperimenterMapLoaded = _groupExperimenterMapLoaded
            self._omeName = _omeName
            self._firstName = _firstName
            self._middleName = _middleName
            self._lastName = _lastName
            self._institution = _institution
            self._ldap = _ldap
            self._email = _email
            self._config = _config
            self._annotationLinksSeq = _annotationLinksSeq
            self._annotationLinksLoaded = _annotationLinksLoaded
            self._annotationLinksCountPerOwner = _annotationLinksCountPerOwner

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::Experimenter', '::omero::model::IObject')

        def ice_id(self, current=None):
            return '::omero::model::Experimenter'

        def ice_staticId():
            return '::omero::model::Experimenter'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def unloadGroupExperimenterMap(self, current=None):
            pass

        def sizeOfGroupExperimenterMap(self, current=None):
            pass

        def copyGroupExperimenterMap(self, current=None):
            pass

        def addGroupExperimenterMap(self, target, current=None):
            pass

        def addAllGroupExperimenterMapSet(self, targets, current=None):
            pass

        def removeGroupExperimenterMap(self, theTarget, current=None):
            pass

        def removeAllGroupExperimenterMapSet(self, targets, current=None):
            pass

        def clearGroupExperimenterMap(self, current=None):
            pass

        def reloadGroupExperimenterMap(self, toCopy, current=None):
            pass

        def getGroupExperimenterMap(self, index, current=None):
            pass

        def setGroupExperimenterMap(self, index, theElement, current=None):
            pass

        def getPrimaryGroupExperimenterMap(self, current=None):
            pass

        def setPrimaryGroupExperimenterMap(self, theElement, current=None):
            pass

        def linkExperimenterGroup(self, addition, current=None):
            pass

        def addGroupExperimenterMapToBoth(self, link, bothSides, current=None):
            pass

        def findGroupExperimenterMap(self, removal, current=None):
            pass

        def unlinkExperimenterGroup(self, removal, current=None):
            pass

        def removeGroupExperimenterMapFromBoth(self, link, bothSides, current=None):
            pass

        def linkedExperimenterGroupList(self, current=None):
            pass

        def getOmeName(self, current=None):
            pass

        def setOmeName(self, theOmeName, current=None):
            pass

        def getFirstName(self, current=None):
            pass

        def setFirstName(self, theFirstName, current=None):
            pass

        def getMiddleName(self, current=None):
            pass

        def setMiddleName(self, theMiddleName, current=None):
            pass

        def getLastName(self, current=None):
            pass

        def setLastName(self, theLastName, current=None):
            pass

        def getInstitution(self, current=None):
            pass

        def setInstitution(self, theInstitution, current=None):
            pass

        def getLdap(self, current=None):
            pass

        def setLdap(self, theLdap, current=None):
            pass

        def getEmail(self, current=None):
            pass

        def setEmail(self, theEmail, current=None):
            pass

        def getConfigAsMap(self, current=None):
            pass

        def getConfig(self, current=None):
            pass

        def setConfig(self, theConfig, current=None):
            pass

        def unloadAnnotationLinks(self, current=None):
            pass

        def sizeOfAnnotationLinks(self, current=None):
            pass

        def copyAnnotationLinks(self, current=None):
            pass

        def addExperimenterAnnotationLink(self, target, current=None):
            pass

        def addAllExperimenterAnnotationLinkSet(self, targets, current=None):
            pass

        def removeExperimenterAnnotationLink(self, theTarget, current=None):
            pass

        def removeAllExperimenterAnnotationLinkSet(self, targets, current=None):
            pass

        def clearAnnotationLinks(self, current=None):
            pass

        def reloadAnnotationLinks(self, toCopy, current=None):
            pass

        def getAnnotationLinksCountPerOwner(self, current=None):
            pass

        def linkAnnotation(self, addition, current=None):
            pass

        def addExperimenterAnnotationLinkToBoth(self, link, bothSides, current=None):
            pass

        def findExperimenterAnnotationLink(self, removal, current=None):
            pass

        def unlinkAnnotation(self, removal, current=None):
            pass

        def removeExperimenterAnnotationLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedAnnotationList(self, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Experimenter)

        __repr__ = __str__

    _M_omero.model.ExperimenterPrx = Ice.createTempClass()
    class ExperimenterPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.Experimenter._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.Experimenter._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.Experimenter._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.Experimenter._op_setVersion.end(self, _r)

        def unloadGroupExperimenterMap(self, _ctx=None):
            return _M_omero.model.Experimenter._op_unloadGroupExperimenterMap.invoke(self, ((), _ctx))

        def begin_unloadGroupExperimenterMap(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_unloadGroupExperimenterMap.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadGroupExperimenterMap(self, _r):
            return _M_omero.model.Experimenter._op_unloadGroupExperimenterMap.end(self, _r)

        def sizeOfGroupExperimenterMap(self, _ctx=None):
            return _M_omero.model.Experimenter._op_sizeOfGroupExperimenterMap.invoke(self, ((), _ctx))

        def begin_sizeOfGroupExperimenterMap(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_sizeOfGroupExperimenterMap.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfGroupExperimenterMap(self, _r):
            return _M_omero.model.Experimenter._op_sizeOfGroupExperimenterMap.end(self, _r)

        def copyGroupExperimenterMap(self, _ctx=None):
            return _M_omero.model.Experimenter._op_copyGroupExperimenterMap.invoke(self, ((), _ctx))

        def begin_copyGroupExperimenterMap(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_copyGroupExperimenterMap.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyGroupExperimenterMap(self, _r):
            return _M_omero.model.Experimenter._op_copyGroupExperimenterMap.end(self, _r)

        def addGroupExperimenterMap(self, target, _ctx=None):
            return _M_omero.model.Experimenter._op_addGroupExperimenterMap.invoke(self, ((target, ), _ctx))

        def begin_addGroupExperimenterMap(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_addGroupExperimenterMap.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addGroupExperimenterMap(self, _r):
            return _M_omero.model.Experimenter._op_addGroupExperimenterMap.end(self, _r)

        def addAllGroupExperimenterMapSet(self, targets, _ctx=None):
            return _M_omero.model.Experimenter._op_addAllGroupExperimenterMapSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllGroupExperimenterMapSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_addAllGroupExperimenterMapSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllGroupExperimenterMapSet(self, _r):
            return _M_omero.model.Experimenter._op_addAllGroupExperimenterMapSet.end(self, _r)

        def removeGroupExperimenterMap(self, theTarget, _ctx=None):
            return _M_omero.model.Experimenter._op_removeGroupExperimenterMap.invoke(self, ((theTarget, ), _ctx))

        def begin_removeGroupExperimenterMap(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_removeGroupExperimenterMap.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeGroupExperimenterMap(self, _r):
            return _M_omero.model.Experimenter._op_removeGroupExperimenterMap.end(self, _r)

        def removeAllGroupExperimenterMapSet(self, targets, _ctx=None):
            return _M_omero.model.Experimenter._op_removeAllGroupExperimenterMapSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllGroupExperimenterMapSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_removeAllGroupExperimenterMapSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllGroupExperimenterMapSet(self, _r):
            return _M_omero.model.Experimenter._op_removeAllGroupExperimenterMapSet.end(self, _r)

        def clearGroupExperimenterMap(self, _ctx=None):
            return _M_omero.model.Experimenter._op_clearGroupExperimenterMap.invoke(self, ((), _ctx))

        def begin_clearGroupExperimenterMap(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_clearGroupExperimenterMap.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearGroupExperimenterMap(self, _r):
            return _M_omero.model.Experimenter._op_clearGroupExperimenterMap.end(self, _r)

        def reloadGroupExperimenterMap(self, toCopy, _ctx=None):
            return _M_omero.model.Experimenter._op_reloadGroupExperimenterMap.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadGroupExperimenterMap(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_reloadGroupExperimenterMap.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadGroupExperimenterMap(self, _r):
            return _M_omero.model.Experimenter._op_reloadGroupExperimenterMap.end(self, _r)

        def getGroupExperimenterMap(self, index, _ctx=None):
            return _M_omero.model.Experimenter._op_getGroupExperimenterMap.invoke(self, ((index, ), _ctx))

        def begin_getGroupExperimenterMap(self, index, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_getGroupExperimenterMap.begin(self, ((index, ), _response, _ex, _sent, _ctx))

        def end_getGroupExperimenterMap(self, _r):
            return _M_omero.model.Experimenter._op_getGroupExperimenterMap.end(self, _r)

        def setGroupExperimenterMap(self, index, theElement, _ctx=None):
            return _M_omero.model.Experimenter._op_setGroupExperimenterMap.invoke(self, ((index, theElement), _ctx))

        def begin_setGroupExperimenterMap(self, index, theElement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_setGroupExperimenterMap.begin(self, ((index, theElement), _response, _ex, _sent, _ctx))

        def end_setGroupExperimenterMap(self, _r):
            return _M_omero.model.Experimenter._op_setGroupExperimenterMap.end(self, _r)

        def getPrimaryGroupExperimenterMap(self, _ctx=None):
            return _M_omero.model.Experimenter._op_getPrimaryGroupExperimenterMap.invoke(self, ((), _ctx))

        def begin_getPrimaryGroupExperimenterMap(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_getPrimaryGroupExperimenterMap.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPrimaryGroupExperimenterMap(self, _r):
            return _M_omero.model.Experimenter._op_getPrimaryGroupExperimenterMap.end(self, _r)

        def setPrimaryGroupExperimenterMap(self, theElement, _ctx=None):
            return _M_omero.model.Experimenter._op_setPrimaryGroupExperimenterMap.invoke(self, ((theElement, ), _ctx))

        def begin_setPrimaryGroupExperimenterMap(self, theElement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_setPrimaryGroupExperimenterMap.begin(self, ((theElement, ), _response, _ex, _sent, _ctx))

        def end_setPrimaryGroupExperimenterMap(self, _r):
            return _M_omero.model.Experimenter._op_setPrimaryGroupExperimenterMap.end(self, _r)

        def linkExperimenterGroup(self, addition, _ctx=None):
            return _M_omero.model.Experimenter._op_linkExperimenterGroup.invoke(self, ((addition, ), _ctx))

        def begin_linkExperimenterGroup(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_linkExperimenterGroup.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkExperimenterGroup(self, _r):
            return _M_omero.model.Experimenter._op_linkExperimenterGroup.end(self, _r)

        def addGroupExperimenterMapToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Experimenter._op_addGroupExperimenterMapToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addGroupExperimenterMapToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_addGroupExperimenterMapToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addGroupExperimenterMapToBoth(self, _r):
            return _M_omero.model.Experimenter._op_addGroupExperimenterMapToBoth.end(self, _r)

        def findGroupExperimenterMap(self, removal, _ctx=None):
            return _M_omero.model.Experimenter._op_findGroupExperimenterMap.invoke(self, ((removal, ), _ctx))

        def begin_findGroupExperimenterMap(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_findGroupExperimenterMap.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findGroupExperimenterMap(self, _r):
            return _M_omero.model.Experimenter._op_findGroupExperimenterMap.end(self, _r)

        def unlinkExperimenterGroup(self, removal, _ctx=None):
            return _M_omero.model.Experimenter._op_unlinkExperimenterGroup.invoke(self, ((removal, ), _ctx))

        def begin_unlinkExperimenterGroup(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_unlinkExperimenterGroup.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkExperimenterGroup(self, _r):
            return _M_omero.model.Experimenter._op_unlinkExperimenterGroup.end(self, _r)

        def removeGroupExperimenterMapFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Experimenter._op_removeGroupExperimenterMapFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeGroupExperimenterMapFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_removeGroupExperimenterMapFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeGroupExperimenterMapFromBoth(self, _r):
            return _M_omero.model.Experimenter._op_removeGroupExperimenterMapFromBoth.end(self, _r)

        def linkedExperimenterGroupList(self, _ctx=None):
            return _M_omero.model.Experimenter._op_linkedExperimenterGroupList.invoke(self, ((), _ctx))

        def begin_linkedExperimenterGroupList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_linkedExperimenterGroupList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedExperimenterGroupList(self, _r):
            return _M_omero.model.Experimenter._op_linkedExperimenterGroupList.end(self, _r)

        def getOmeName(self, _ctx=None):
            return _M_omero.model.Experimenter._op_getOmeName.invoke(self, ((), _ctx))

        def begin_getOmeName(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_getOmeName.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getOmeName(self, _r):
            return _M_omero.model.Experimenter._op_getOmeName.end(self, _r)

        def setOmeName(self, theOmeName, _ctx=None):
            return _M_omero.model.Experimenter._op_setOmeName.invoke(self, ((theOmeName, ), _ctx))

        def begin_setOmeName(self, theOmeName, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_setOmeName.begin(self, ((theOmeName, ), _response, _ex, _sent, _ctx))

        def end_setOmeName(self, _r):
            return _M_omero.model.Experimenter._op_setOmeName.end(self, _r)

        def getFirstName(self, _ctx=None):
            return _M_omero.model.Experimenter._op_getFirstName.invoke(self, ((), _ctx))

        def begin_getFirstName(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_getFirstName.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getFirstName(self, _r):
            return _M_omero.model.Experimenter._op_getFirstName.end(self, _r)

        def setFirstName(self, theFirstName, _ctx=None):
            return _M_omero.model.Experimenter._op_setFirstName.invoke(self, ((theFirstName, ), _ctx))

        def begin_setFirstName(self, theFirstName, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_setFirstName.begin(self, ((theFirstName, ), _response, _ex, _sent, _ctx))

        def end_setFirstName(self, _r):
            return _M_omero.model.Experimenter._op_setFirstName.end(self, _r)

        def getMiddleName(self, _ctx=None):
            return _M_omero.model.Experimenter._op_getMiddleName.invoke(self, ((), _ctx))

        def begin_getMiddleName(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_getMiddleName.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getMiddleName(self, _r):
            return _M_omero.model.Experimenter._op_getMiddleName.end(self, _r)

        def setMiddleName(self, theMiddleName, _ctx=None):
            return _M_omero.model.Experimenter._op_setMiddleName.invoke(self, ((theMiddleName, ), _ctx))

        def begin_setMiddleName(self, theMiddleName, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_setMiddleName.begin(self, ((theMiddleName, ), _response, _ex, _sent, _ctx))

        def end_setMiddleName(self, _r):
            return _M_omero.model.Experimenter._op_setMiddleName.end(self, _r)

        def getLastName(self, _ctx=None):
            return _M_omero.model.Experimenter._op_getLastName.invoke(self, ((), _ctx))

        def begin_getLastName(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_getLastName.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getLastName(self, _r):
            return _M_omero.model.Experimenter._op_getLastName.end(self, _r)

        def setLastName(self, theLastName, _ctx=None):
            return _M_omero.model.Experimenter._op_setLastName.invoke(self, ((theLastName, ), _ctx))

        def begin_setLastName(self, theLastName, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_setLastName.begin(self, ((theLastName, ), _response, _ex, _sent, _ctx))

        def end_setLastName(self, _r):
            return _M_omero.model.Experimenter._op_setLastName.end(self, _r)

        def getInstitution(self, _ctx=None):
            return _M_omero.model.Experimenter._op_getInstitution.invoke(self, ((), _ctx))

        def begin_getInstitution(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_getInstitution.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getInstitution(self, _r):
            return _M_omero.model.Experimenter._op_getInstitution.end(self, _r)

        def setInstitution(self, theInstitution, _ctx=None):
            return _M_omero.model.Experimenter._op_setInstitution.invoke(self, ((theInstitution, ), _ctx))

        def begin_setInstitution(self, theInstitution, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_setInstitution.begin(self, ((theInstitution, ), _response, _ex, _sent, _ctx))

        def end_setInstitution(self, _r):
            return _M_omero.model.Experimenter._op_setInstitution.end(self, _r)

        def getLdap(self, _ctx=None):
            return _M_omero.model.Experimenter._op_getLdap.invoke(self, ((), _ctx))

        def begin_getLdap(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_getLdap.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getLdap(self, _r):
            return _M_omero.model.Experimenter._op_getLdap.end(self, _r)

        def setLdap(self, theLdap, _ctx=None):
            return _M_omero.model.Experimenter._op_setLdap.invoke(self, ((theLdap, ), _ctx))

        def begin_setLdap(self, theLdap, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_setLdap.begin(self, ((theLdap, ), _response, _ex, _sent, _ctx))

        def end_setLdap(self, _r):
            return _M_omero.model.Experimenter._op_setLdap.end(self, _r)

        def getEmail(self, _ctx=None):
            return _M_omero.model.Experimenter._op_getEmail.invoke(self, ((), _ctx))

        def begin_getEmail(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_getEmail.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getEmail(self, _r):
            return _M_omero.model.Experimenter._op_getEmail.end(self, _r)

        def setEmail(self, theEmail, _ctx=None):
            return _M_omero.model.Experimenter._op_setEmail.invoke(self, ((theEmail, ), _ctx))

        def begin_setEmail(self, theEmail, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_setEmail.begin(self, ((theEmail, ), _response, _ex, _sent, _ctx))

        def end_setEmail(self, _r):
            return _M_omero.model.Experimenter._op_setEmail.end(self, _r)

        def getConfigAsMap(self, _ctx=None):
            return _M_omero.model.Experimenter._op_getConfigAsMap.invoke(self, ((), _ctx))

        def begin_getConfigAsMap(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_getConfigAsMap.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getConfigAsMap(self, _r):
            return _M_omero.model.Experimenter._op_getConfigAsMap.end(self, _r)

        def getConfig(self, _ctx=None):
            return _M_omero.model.Experimenter._op_getConfig.invoke(self, ((), _ctx))

        def begin_getConfig(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_getConfig.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getConfig(self, _r):
            return _M_omero.model.Experimenter._op_getConfig.end(self, _r)

        def setConfig(self, theConfig, _ctx=None):
            return _M_omero.model.Experimenter._op_setConfig.invoke(self, ((theConfig, ), _ctx))

        def begin_setConfig(self, theConfig, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_setConfig.begin(self, ((theConfig, ), _response, _ex, _sent, _ctx))

        def end_setConfig(self, _r):
            return _M_omero.model.Experimenter._op_setConfig.end(self, _r)

        def unloadAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Experimenter._op_unloadAnnotationLinks.invoke(self, ((), _ctx))

        def begin_unloadAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_unloadAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadAnnotationLinks(self, _r):
            return _M_omero.model.Experimenter._op_unloadAnnotationLinks.end(self, _r)

        def sizeOfAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Experimenter._op_sizeOfAnnotationLinks.invoke(self, ((), _ctx))

        def begin_sizeOfAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_sizeOfAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfAnnotationLinks(self, _r):
            return _M_omero.model.Experimenter._op_sizeOfAnnotationLinks.end(self, _r)

        def copyAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Experimenter._op_copyAnnotationLinks.invoke(self, ((), _ctx))

        def begin_copyAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_copyAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyAnnotationLinks(self, _r):
            return _M_omero.model.Experimenter._op_copyAnnotationLinks.end(self, _r)

        def addExperimenterAnnotationLink(self, target, _ctx=None):
            return _M_omero.model.Experimenter._op_addExperimenterAnnotationLink.invoke(self, ((target, ), _ctx))

        def begin_addExperimenterAnnotationLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_addExperimenterAnnotationLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addExperimenterAnnotationLink(self, _r):
            return _M_omero.model.Experimenter._op_addExperimenterAnnotationLink.end(self, _r)

        def addAllExperimenterAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Experimenter._op_addAllExperimenterAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllExperimenterAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_addAllExperimenterAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllExperimenterAnnotationLinkSet(self, _r):
            return _M_omero.model.Experimenter._op_addAllExperimenterAnnotationLinkSet.end(self, _r)

        def removeExperimenterAnnotationLink(self, theTarget, _ctx=None):
            return _M_omero.model.Experimenter._op_removeExperimenterAnnotationLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeExperimenterAnnotationLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_removeExperimenterAnnotationLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeExperimenterAnnotationLink(self, _r):
            return _M_omero.model.Experimenter._op_removeExperimenterAnnotationLink.end(self, _r)

        def removeAllExperimenterAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Experimenter._op_removeAllExperimenterAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllExperimenterAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_removeAllExperimenterAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllExperimenterAnnotationLinkSet(self, _r):
            return _M_omero.model.Experimenter._op_removeAllExperimenterAnnotationLinkSet.end(self, _r)

        def clearAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Experimenter._op_clearAnnotationLinks.invoke(self, ((), _ctx))

        def begin_clearAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_clearAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearAnnotationLinks(self, _r):
            return _M_omero.model.Experimenter._op_clearAnnotationLinks.end(self, _r)

        def reloadAnnotationLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Experimenter._op_reloadAnnotationLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadAnnotationLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_reloadAnnotationLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadAnnotationLinks(self, _r):
            return _M_omero.model.Experimenter._op_reloadAnnotationLinks.end(self, _r)

        def getAnnotationLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Experimenter._op_getAnnotationLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getAnnotationLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_getAnnotationLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAnnotationLinksCountPerOwner(self, _r):
            return _M_omero.model.Experimenter._op_getAnnotationLinksCountPerOwner.end(self, _r)

        def linkAnnotation(self, addition, _ctx=None):
            return _M_omero.model.Experimenter._op_linkAnnotation.invoke(self, ((addition, ), _ctx))

        def begin_linkAnnotation(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_linkAnnotation.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkAnnotation(self, _r):
            return _M_omero.model.Experimenter._op_linkAnnotation.end(self, _r)

        def addExperimenterAnnotationLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Experimenter._op_addExperimenterAnnotationLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addExperimenterAnnotationLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_addExperimenterAnnotationLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addExperimenterAnnotationLinkToBoth(self, _r):
            return _M_omero.model.Experimenter._op_addExperimenterAnnotationLinkToBoth.end(self, _r)

        def findExperimenterAnnotationLink(self, removal, _ctx=None):
            return _M_omero.model.Experimenter._op_findExperimenterAnnotationLink.invoke(self, ((removal, ), _ctx))

        def begin_findExperimenterAnnotationLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_findExperimenterAnnotationLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findExperimenterAnnotationLink(self, _r):
            return _M_omero.model.Experimenter._op_findExperimenterAnnotationLink.end(self, _r)

        def unlinkAnnotation(self, removal, _ctx=None):
            return _M_omero.model.Experimenter._op_unlinkAnnotation.invoke(self, ((removal, ), _ctx))

        def begin_unlinkAnnotation(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_unlinkAnnotation.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkAnnotation(self, _r):
            return _M_omero.model.Experimenter._op_unlinkAnnotation.end(self, _r)

        def removeExperimenterAnnotationLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Experimenter._op_removeExperimenterAnnotationLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeExperimenterAnnotationLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_removeExperimenterAnnotationLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeExperimenterAnnotationLinkFromBoth(self, _r):
            return _M_omero.model.Experimenter._op_removeExperimenterAnnotationLinkFromBoth.end(self, _r)

        def linkedAnnotationList(self, _ctx=None):
            return _M_omero.model.Experimenter._op_linkedAnnotationList.invoke(self, ((), _ctx))

        def begin_linkedAnnotationList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Experimenter._op_linkedAnnotationList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedAnnotationList(self, _r):
            return _M_omero.model.Experimenter._op_linkedAnnotationList.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.ExperimenterPrx.ice_checkedCast(proxy, '::omero::model::Experimenter', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.ExperimenterPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Experimenter'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_ExperimenterPrx = IcePy.defineProxy('::omero::model::Experimenter', ExperimenterPrx)

    _M_omero.model._t_Experimenter = IcePy.declareClass('::omero::model::Experimenter')

    _M_omero.model._t_Experimenter = IcePy.defineClass('::omero::model::Experimenter', Experimenter, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_groupExperimenterMapSeq', (), _M_omero.model._t_ExperimenterGroupExperimenterMapSeq, False, 0),
        ('_groupExperimenterMapLoaded', (), IcePy._t_bool, False, 0),
        ('_omeName', (), _M_omero._t_RString, False, 0),
        ('_firstName', (), _M_omero._t_RString, False, 0),
        ('_middleName', (), _M_omero._t_RString, False, 0),
        ('_lastName', (), _M_omero._t_RString, False, 0),
        ('_institution', (), _M_omero._t_RString, False, 0),
        ('_ldap', (), _M_omero._t_RBool, False, 0),
        ('_email', (), _M_omero._t_RString, False, 0),
        ('_config', (), _M_omero.api._t_NamedValueList, False, 0),
        ('_annotationLinksSeq', (), _M_omero.model._t_ExperimenterAnnotationLinksSeq, False, 0),
        ('_annotationLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0)
    ))
    Experimenter._ice_type = _M_omero.model._t_Experimenter

    Experimenter._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Experimenter._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Experimenter._op_unloadGroupExperimenterMap = IcePy.Operation('unloadGroupExperimenterMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Experimenter._op_sizeOfGroupExperimenterMap = IcePy.Operation('sizeOfGroupExperimenterMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Experimenter._op_copyGroupExperimenterMap = IcePy.Operation('copyGroupExperimenterMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ExperimenterGroupExperimenterMapSeq, False, 0), ())
    Experimenter._op_addGroupExperimenterMap = IcePy.Operation('addGroupExperimenterMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_GroupExperimenterMap, False, 0),), (), None, ())
    Experimenter._op_addAllGroupExperimenterMapSet = IcePy.Operation('addAllGroupExperimenterMapSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimenterGroupExperimenterMapSeq, False, 0),), (), None, ())
    Experimenter._op_removeGroupExperimenterMap = IcePy.Operation('removeGroupExperimenterMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_GroupExperimenterMap, False, 0),), (), None, ())
    Experimenter._op_removeAllGroupExperimenterMapSet = IcePy.Operation('removeAllGroupExperimenterMapSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimenterGroupExperimenterMapSeq, False, 0),), (), None, ())
    Experimenter._op_clearGroupExperimenterMap = IcePy.Operation('clearGroupExperimenterMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Experimenter._op_reloadGroupExperimenterMap = IcePy.Operation('reloadGroupExperimenterMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Experimenter, False, 0),), (), None, ())
    Experimenter._op_getGroupExperimenterMap = IcePy.Operation('getGroupExperimenterMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0),), (), ((), _M_omero.model._t_GroupExperimenterMap, False, 0), ())
    Experimenter._op_setGroupExperimenterMap = IcePy.Operation('setGroupExperimenterMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0), ((), _M_omero.model._t_GroupExperimenterMap, False, 0)), (), ((), _M_omero.model._t_GroupExperimenterMap, False, 0), ())
    Experimenter._op_getPrimaryGroupExperimenterMap = IcePy.Operation('getPrimaryGroupExperimenterMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_GroupExperimenterMap, False, 0), ())
    Experimenter._op_setPrimaryGroupExperimenterMap = IcePy.Operation('setPrimaryGroupExperimenterMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_GroupExperimenterMap, False, 0),), (), ((), _M_omero.model._t_GroupExperimenterMap, False, 0), ())
    Experimenter._op_linkExperimenterGroup = IcePy.Operation('linkExperimenterGroup', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimenterGroup, False, 0),), (), ((), _M_omero.model._t_GroupExperimenterMap, False, 0), ())
    Experimenter._op_addGroupExperimenterMapToBoth = IcePy.Operation('addGroupExperimenterMapToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_GroupExperimenterMap, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Experimenter._op_findGroupExperimenterMap = IcePy.Operation('findGroupExperimenterMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimenterGroup, False, 0),), (), ((), _M_omero.model._t_ExperimenterGroupExperimenterMapSeq, False, 0), ())
    Experimenter._op_unlinkExperimenterGroup = IcePy.Operation('unlinkExperimenterGroup', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimenterGroup, False, 0),), (), None, ())
    Experimenter._op_removeGroupExperimenterMapFromBoth = IcePy.Operation('removeGroupExperimenterMapFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_GroupExperimenterMap, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Experimenter._op_linkedExperimenterGroupList = IcePy.Operation('linkedExperimenterGroupList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ExperimenterLinkedExperimenterGroupSeq, False, 0), ())
    Experimenter._op_getOmeName = IcePy.Operation('getOmeName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Experimenter._op_setOmeName = IcePy.Operation('setOmeName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Experimenter._op_getFirstName = IcePy.Operation('getFirstName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Experimenter._op_setFirstName = IcePy.Operation('setFirstName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Experimenter._op_getMiddleName = IcePy.Operation('getMiddleName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Experimenter._op_setMiddleName = IcePy.Operation('setMiddleName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Experimenter._op_getLastName = IcePy.Operation('getLastName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Experimenter._op_setLastName = IcePy.Operation('setLastName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Experimenter._op_getInstitution = IcePy.Operation('getInstitution', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Experimenter._op_setInstitution = IcePy.Operation('setInstitution', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Experimenter._op_getLdap = IcePy.Operation('getLdap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RBool, False, 0), ())
    Experimenter._op_setLdap = IcePy.Operation('setLdap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RBool, False, 0),), (), None, ())
    Experimenter._op_getEmail = IcePy.Operation('getEmail', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Experimenter._op_setEmail = IcePy.Operation('setEmail', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Experimenter._op_getConfigAsMap = IcePy.Operation('getConfigAsMap', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.api._t_StringStringMap, False, 0), ())
    Experimenter._op_getConfig = IcePy.Operation('getConfig', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.api._t_NamedValueList, False, 0), ())
    Experimenter._op_setConfig = IcePy.Operation('setConfig', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.api._t_NamedValueList, False, 0),), (), None, ())
    Experimenter._op_unloadAnnotationLinks = IcePy.Operation('unloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Experimenter._op_sizeOfAnnotationLinks = IcePy.Operation('sizeOfAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Experimenter._op_copyAnnotationLinks = IcePy.Operation('copyAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ExperimenterAnnotationLinksSeq, False, 0), ())
    Experimenter._op_addExperimenterAnnotationLink = IcePy.Operation('addExperimenterAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimenterAnnotationLink, False, 0),), (), None, ())
    Experimenter._op_addAllExperimenterAnnotationLinkSet = IcePy.Operation('addAllExperimenterAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimenterAnnotationLinksSeq, False, 0),), (), None, ())
    Experimenter._op_removeExperimenterAnnotationLink = IcePy.Operation('removeExperimenterAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimenterAnnotationLink, False, 0),), (), None, ())
    Experimenter._op_removeAllExperimenterAnnotationLinkSet = IcePy.Operation('removeAllExperimenterAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimenterAnnotationLinksSeq, False, 0),), (), None, ())
    Experimenter._op_clearAnnotationLinks = IcePy.Operation('clearAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Experimenter._op_reloadAnnotationLinks = IcePy.Operation('reloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Experimenter, False, 0),), (), None, ())
    Experimenter._op_getAnnotationLinksCountPerOwner = IcePy.Operation('getAnnotationLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Experimenter._op_linkAnnotation = IcePy.Operation('linkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_ExperimenterAnnotationLink, False, 0), ())
    Experimenter._op_addExperimenterAnnotationLinkToBoth = IcePy.Operation('addExperimenterAnnotationLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimenterAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Experimenter._op_findExperimenterAnnotationLink = IcePy.Operation('findExperimenterAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_ExperimenterAnnotationLinksSeq, False, 0), ())
    Experimenter._op_unlinkAnnotation = IcePy.Operation('unlinkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    Experimenter._op_removeExperimenterAnnotationLinkFromBoth = IcePy.Operation('removeExperimenterAnnotationLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ExperimenterAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Experimenter._op_linkedAnnotationList = IcePy.Operation('linkedAnnotationList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ExperimenterLinkedAnnotationSeq, False, 0), ())

    _M_omero.model.Experimenter = Experimenter
    del Experimenter

    _M_omero.model.ExperimenterPrx = ExperimenterPrx
    del ExperimenterPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `ServicesF.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_ServerErrors_ice
import omero_System_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.api
__name__ = 'omero.api'

if 'ServiceInterface' not in _M_omero.api.__dict__:
    _M_omero.api.ServiceInterface = Ice.createTempClass()
    class ServiceInterface(Ice.Object):
        """
        Service marker similar to ome.api.ServiceInterface. Any object which
        IS-A ServiceInterface but IS-NOT-A StatefulServiceInterface (below)
        is by definition a ""stateless service""
        """
        def __init__(self):
            if Ice.getType(self) == _M_omero.api.ServiceInterface:
                raise RuntimeError('omero.api.ServiceInterface is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::api::ServiceInterface')

        def ice_id(self, current=None):
            return '::omero::api::ServiceInterface'

        def ice_staticId():
            return '::omero::api::ServiceInterface'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.api._t_ServiceInterface)

        __repr__ = __str__

    _M_omero.api.ServiceInterfacePrx = Ice.createTempClass()
    class ServiceInterfacePrx(Ice.ObjectPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.api.ServiceInterfacePrx.ice_checkedCast(proxy, '::omero::api::ServiceInterface', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.api.ServiceInterfacePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::api::ServiceInterface'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.api._t_ServiceInterfacePrx = IcePy.defineProxy('::omero::api::ServiceInterface', ServiceInterfacePrx)

    _M_omero.api._t_ServiceInterface = IcePy.defineClass('::omero::api::ServiceInterface', ServiceInterface, -1, (), True, False, None, (), ())
    ServiceInterface._ice_type = _M_omero.api._t_ServiceInterface

    _M_omero.api.ServiceInterface = ServiceInterface
    del ServiceInterface

    _M_omero.api.ServiceInterfacePrx = ServiceInterfacePrx
    del ServiceInterfacePrx

if '_t_ServiceList' not in _M_omero.api.__dict__:
    _M_omero.api._t_ServiceList = IcePy.defineSequence('::omero::api::ServiceList', (), _M_omero.api._t_ServiceInterfacePrx)

if 'StatefulServiceInterface' not in _M_omero.api.__dict__:
    _M_omero.api.StatefulServiceInterface = Ice.createTempClass()
    class StatefulServiceInterface(_M_omero.api.ServiceInterface):
        """
        Service marker for stateful services which permits the closing
        of a particular service before the destruction of the session.
        """
        def __init__(self):
            if Ice.getType(self) == _M_omero.api.StatefulServiceInterface:
                raise RuntimeError('omero.api.StatefulServiceInterface is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::api::ServiceInterface', '::omero::api::StatefulServiceInterface')

        def ice_id(self, current=None):
            return '::omero::api::StatefulServiceInterface'

        def ice_staticId():
            return '::omero::api::StatefulServiceInterface'
        ice_staticId = staticmethod(ice_staticId)

        def passivate_async(self, _cb, current=None):
            """
            Causes the blitz server to store the service implementation to disk
            to free memory. This is typically done automatically by the server
            when a pre-defined memory limit is reached, but can be used by the
            client if it clear that a stateful service will not be used for some
            time.
            Activation will happen automatically whether passivation was done
            manually or automatically.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            """
            pass

        def activate_async(self, _cb, current=None):
            """
            Load a service implementation from disk if it was previously
            passivated. It is unnecessary to call this method since activation
            happens automatically, but calling this may prevent a short
            lapse when the service is first accessed after passivation.
            It is safe to call this method at any time, even when the service
            is not passivated.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            """
            pass

        def close_async(self, _cb, current=None):
            """
            Frees all resources -- passivated or active -- for the given
            stateful service and removes its name from the object adapter.
            Any further method calls will fail with a Ice::NoSuchObjectException.
            Note: with JavaEE, the close method was called publicly,
            and internally this called destroy(). As of the OmeroBlitz
            migration, this functionality has been combined.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            """
            pass

        def getCurrentEventContext_async(self, _cb, current=None):
            """
            To free clients from tracking the mapping from session to stateful
            service, each stateful service can returns its own context information.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.api._t_StatefulServiceInterface)

        __repr__ = __str__

    _M_omero.api.StatefulServiceInterfacePrx = Ice.createTempClass()
    class StatefulServiceInterfacePrx(_M_omero.api.ServiceInterfacePrx):

        """
        Causes the blitz server to store the service implementation to disk
        to free memory. This is typically done automatically by the server
        when a pre-defined memory limit is reached, but can be used by the
        client if it clear that a stateful service will not be used for some
        time.
        Activation will happen automatically whether passivation was done
        manually or automatically.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def passivate(self, _ctx=None):
            return _M_omero.api.StatefulServiceInterface._op_passivate.invoke(self, ((), _ctx))

        """
        Causes the blitz server to store the service implementation to disk
        to free memory. This is typically done automatically by the server
        when a pre-defined memory limit is reached, but can be used by the
        client if it clear that a stateful service will not be used for some
        time.
        Activation will happen automatically whether passivation was done
        manually or automatically.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_passivate(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.StatefulServiceInterface._op_passivate.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Causes the blitz server to store the service implementation to disk
        to free memory. This is typically done automatically by the server
        when a pre-defined memory limit is reached, but can be used by the
        client if it clear that a stateful service will not be used for some
        time.
        Activation will happen automatically whether passivation was done
        manually or automatically.
        Arguments:
        """
        def end_passivate(self, _r):
            return _M_omero.api.StatefulServiceInterface._op_passivate.end(self, _r)

        """
        Load a service implementation from disk if it was previously
        passivated. It is unnecessary to call this method since activation
        happens automatically, but calling this may prevent a short
        lapse when the service is first accessed after passivation.
        It is safe to call this method at any time, even when the service
        is not passivated.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def activate(self, _ctx=None):
            return _M_omero.api.StatefulServiceInterface._op_activate.invoke(self, ((), _ctx))

        """
        Load a service implementation from disk if it was previously
        passivated. It is unnecessary to call this method since activation
        happens automatically, but calling this may prevent a short
        lapse when the service is first accessed after passivation.
        It is safe to call this method at any time, even when the service
        is not passivated.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_activate(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.StatefulServiceInterface._op_activate.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Load a service implementation from disk if it was previously
        passivated. It is unnecessary to call this method since activation
        happens automatically, but calling this may prevent a short
        lapse when the service is first accessed after passivation.
        It is safe to call this method at any time, even when the service
        is not passivated.
        Arguments:
        """
        def end_activate(self, _r):
            return _M_omero.api.StatefulServiceInterface._op_activate.end(self, _r)

        """
        Frees all resources -- passivated or active -- for the given
        stateful service and removes its name from the object adapter.
        Any further method calls will fail with a Ice::NoSuchObjectException.
        Note: with JavaEE, the close method was called publicly,
        and internally this called destroy(). As of the OmeroBlitz
        migration, this functionality has been combined.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def close(self, _ctx=None):
            return _M_omero.api.StatefulServiceInterface._op_close.invoke(self, ((), _ctx))

        """
        Frees all resources -- passivated or active -- for the given
        stateful service and removes its name from the object adapter.
        Any further method calls will fail with a Ice::NoSuchObjectException.
        Note: with JavaEE, the close method was called publicly,
        and internally this called destroy(). As of the OmeroBlitz
        migration, this functionality has been combined.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_close(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.StatefulServiceInterface._op_close.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Frees all resources -- passivated or active -- for the given
        stateful service and removes its name from the object adapter.
        Any further method calls will fail with a Ice::NoSuchObjectException.
        Note: with JavaEE, the close method was called publicly,
        and internally this called destroy(). As of the OmeroBlitz
        migration, this functionality has been combined.
        Arguments:
        """
        def end_close(self, _r):
            return _M_omero.api.StatefulServiceInterface._op_close.end(self, _r)

        """
        To free clients from tracking the mapping from session to stateful
        service, each stateful service can returns its own context information.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def getCurrentEventContext(self, _ctx=None):
            return _M_omero.api.StatefulServiceInterface._op_getCurrentEventContext.invoke(self, ((), _ctx))

        """
        To free clients from tracking the mapping from session to stateful
        service, each stateful service can returns its own context information.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getCurrentEventContext(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.api.StatefulServiceInterface._op_getCurrentEventContext.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        To free clients from tracking the mapping from session to stateful
        service, each stateful service can returns its own context information.
        Arguments:
        """
        def end_getCurrentEventContext(self, _r):
            return _M_omero.api.StatefulServiceInterface._op_getCurrentEventContext.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.api.StatefulServiceInterfacePrx.ice_checkedCast(proxy, '::omero::api::StatefulServiceInterface', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.api.StatefulServiceInterfacePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::api::StatefulServiceInterface'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.api._t_StatefulServiceInterfacePrx = IcePy.defineProxy('::omero::api::StatefulServiceInterface', StatefulServiceInterfacePrx)

    _M_omero.api._t_StatefulServiceInterface = IcePy.defineClass('::omero::api::StatefulServiceInterface', StatefulServiceInterface, -1, (), True, False, None, (_M_omero.api._t_ServiceInterface,), ())
    StatefulServiceInterface._ice_type = _M_omero.api._t_StatefulServiceInterface

    StatefulServiceInterface._op_passivate = IcePy.Operation('passivate', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (), (), None, (_M_omero._t_ServerError,))
    StatefulServiceInterface._op_activate = IcePy.Operation('activate', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (), (), None, (_M_omero._t_ServerError,))
    StatefulServiceInterface._op_close = IcePy.Operation('close', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (), (), None, (_M_omero._t_ServerError,))
    StatefulServiceInterface._op_getCurrentEventContext = IcePy.Operation('getCurrentEventContext', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (), (), ((), _M_omero.sys._t_EventContext, False, 0), (_M_omero._t_ServerError,))

    _M_omero.api.StatefulServiceInterface = StatefulServiceInterface
    del StatefulServiceInterface

    _M_omero.api.StatefulServiceInterfacePrx = StatefulServiceInterfacePrx
    del StatefulServiceInterfacePrx

if 'IAdmin' not in _M_omero.api.__dict__:
    _M_omero.api._t_IAdmin = IcePy.declareClass('::omero::api::IAdmin')
    _M_omero.api._t_IAdminPrx = IcePy.declareProxy('::omero::api::IAdmin')

if 'IConfig' not in _M_omero.api.__dict__:
    _M_omero.api._t_IConfig = IcePy.declareClass('::omero::api::IConfig')
    _M_omero.api._t_IConfigPrx = IcePy.declareProxy('::omero::api::IConfig')

if 'IContainer' not in _M_omero.api.__dict__:
    _M_omero.api._t_IContainer = IcePy.declareClass('::omero::api::IContainer')
    _M_omero.api._t_IContainerPrx = IcePy.declareProxy('::omero::api::IContainer')

if 'ILdap' not in _M_omero.api.__dict__:
    _M_omero.api._t_ILdap = IcePy.declareClass('::omero::api::ILdap')
    _M_omero.api._t_ILdapPrx = IcePy.declareProxy('::omero::api::ILdap')

if 'IMetadata' not in _M_omero.api.__dict__:
    _M_omero.api._t_IMetadata = IcePy.declareClass('::omero::api::IMetadata')
    _M_omero.api._t_IMetadataPrx = IcePy.declareProxy('::omero::api::IMetadata')

if 'IPixels' not in _M_omero.api.__dict__:
    _M_omero.api._t_IPixels = IcePy.declareClass('::omero::api::IPixels')
    _M_omero.api._t_IPixelsPrx = IcePy.declareProxy('::omero::api::IPixels')

if 'IProjection' not in _M_omero.api.__dict__:
    _M_omero.api._t_IProjection = IcePy.declareClass('::omero::api::IProjection')
    _M_omero.api._t_IProjectionPrx = IcePy.declareProxy('::omero::api::IProjection')

if 'IQuery' not in _M_omero.api.__dict__:
    _M_omero.api._t_IQuery = IcePy.declareClass('::omero::api::IQuery')
    _M_omero.api._t_IQueryPrx = IcePy.declareProxy('::omero::api::IQuery')

if 'IRoi' not in _M_omero.api.__dict__:
    _M_omero.api._t_IRoi = IcePy.declareClass('::omero::api::IRoi')
    _M_omero.api._t_IRoiPrx = IcePy.declareProxy('::omero::api::IRoi')

if 'IScript' not in _M_omero.api.__dict__:
    _M_omero.api._t_IScript = IcePy.declareClass('::omero::api::IScript')
    _M_omero.api._t_IScriptPrx = IcePy.declareProxy('::omero::api::IScript')

if 'ISession' not in _M_omero.api.__dict__:
    _M_omero.api._t_ISession = IcePy.declareClass('::omero::api::ISession')
    _M_omero.api._t_ISessionPrx = IcePy.declareProxy('::omero::api::ISession')

if 'IShare' not in _M_omero.api.__dict__:
    _M_omero.api._t_IShare = IcePy.declareClass('::omero::api::IShare')
    _M_omero.api._t_ISharePrx = IcePy.declareProxy('::omero::api::IShare')

if 'ITypes' not in _M_omero.api.__dict__:
    _M_omero.api._t_ITypes = IcePy.declareClass('::omero::api::ITypes')
    _M_omero.api._t_ITypesPrx = IcePy.declareProxy('::omero::api::ITypes')

if 'IUpdate' not in _M_omero.api.__dict__:
    _M_omero.api._t_IUpdate = IcePy.declareClass('::omero::api::IUpdate')
    _M_omero.api._t_IUpdatePrx = IcePy.declareProxy('::omero::api::IUpdate')

if 'IRenderingSettings' not in _M_omero.api.__dict__:
    _M_omero.api._t_IRenderingSettings = IcePy.declareClass('::omero::api::IRenderingSettings')
    _M_omero.api._t_IRenderingSettingsPrx = IcePy.declareProxy('::omero::api::IRenderingSettings')

if 'IRepositoryInfo' not in _M_omero.api.__dict__:
    _M_omero.api._t_IRepositoryInfo = IcePy.declareClass('::omero::api::IRepositoryInfo')
    _M_omero.api._t_IRepositoryInfoPrx = IcePy.declareProxy('::omero::api::IRepositoryInfo')

if 'ITimeline' not in _M_omero.api.__dict__:
    _M_omero.api._t_ITimeline = IcePy.declareClass('::omero::api::ITimeline')
    _M_omero.api._t_ITimelinePrx = IcePy.declareProxy('::omero::api::ITimeline')

if 'Exporter' not in _M_omero.api.__dict__:
    _M_omero.api._t_Exporter = IcePy.declareClass('::omero::api::Exporter')
    _M_omero.api._t_ExporterPrx = IcePy.declareProxy('::omero::api::Exporter')

if 'JobHandle' not in _M_omero.api.__dict__:
    _M_omero.api._t_JobHandle = IcePy.declareClass('::omero::api::JobHandle')
    _M_omero.api._t_JobHandlePrx = IcePy.declareProxy('::omero::api::JobHandle')

if 'RawFileStore' not in _M_omero.api.__dict__:
    _M_omero.api._t_RawFileStore = IcePy.declareClass('::omero::api::RawFileStore')
    _M_omero.api._t_RawFileStorePrx = IcePy.declareProxy('::omero::api::RawFileStore')

if 'RawPixelsStore' not in _M_omero.api.__dict__:
    _M_omero.api._t_RawPixelsStore = IcePy.declareClass('::omero::api::RawPixelsStore')
    _M_omero.api._t_RawPixelsStorePrx = IcePy.declareProxy('::omero::api::RawPixelsStore')

if 'RenderingEngine' not in _M_omero.api.__dict__:
    _M_omero.api._t_RenderingEngine = IcePy.declareClass('::omero::api::RenderingEngine')
    _M_omero.api._t_RenderingEnginePrx = IcePy.declareProxy('::omero::api::RenderingEngine')

if 'Search' not in _M_omero.api.__dict__:
    _M_omero.api._t_Search = IcePy.declareClass('::omero::api::Search')
    _M_omero.api._t_SearchPrx = IcePy.declareProxy('::omero::api::Search')

if 'ThumbnailStore' not in _M_omero.api.__dict__:
    _M_omero.api._t_ThumbnailStore = IcePy.declareClass('::omero::api::ThumbnailStore')
    _M_omero.api._t_ThumbnailStorePrx = IcePy.declareProxy('::omero::api::ThumbnailStore')

# End of module omero.api

__name__ = 'omero'

# Start of module omero.grid
_M_omero.grid = Ice.openModule('omero.grid')
__name__ = 'omero.grid'

if 'ManagedRepository' not in _M_omero.grid.__dict__:
    _M_omero.grid._t_ManagedRepository = IcePy.declareClass('::omero::grid::ManagedRepository')
    _M_omero.grid._t_ManagedRepositoryPrx = IcePy.declareProxy('::omero::grid::ManagedRepository')

if 'ScriptProcessor' not in _M_omero.grid.__dict__:
    _M_omero.grid._t_ScriptProcessor = IcePy.declareClass('::omero::grid::ScriptProcessor')
    _M_omero.grid._t_ScriptProcessorPrx = IcePy.declareProxy('::omero::grid::ScriptProcessor')

if 'SharedResources' not in _M_omero.grid.__dict__:
    _M_omero.grid._t_SharedResources = IcePy.declareClass('::omero::grid::SharedResources')
    _M_omero.grid._t_SharedResourcesPrx = IcePy.declareProxy('::omero::grid::SharedResources')

if 'Table' not in _M_omero.grid.__dict__:
    _M_omero.grid._t_Table = IcePy.declareClass('::omero::grid::Table')
    _M_omero.grid._t_TablePrx = IcePy.declareProxy('::omero::grid::Table')

# End of module omero.grid

__name__ = 'omero'

# End of module omero
